==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/es/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Español',

# common
'L_PLUXML_VERSION'				=> 'Versión de PluXml',
'L_HOMEPAGE'					=> 'Inicio',
'L_UNCLASSIFIED'				=> 'Sin categoría',
'L_INFO_PHP_VERSION'			=> 'Versión de PHP',
'L_INFO_MAGIC_QUOTES'			=> 'Estado de las «comillas mágicas» («magic quotes»)',
'L_INFO_CHARSET'				=> 'codificación',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'No se encontró el tema principal de PluXml',
'L_ERR_FILE_NOTFOUND'			=> 'No se encontró el archivo destino de PluXml',
'L_ERR_PAGE_NOT_FOUND'			=> 'No se encontró la página',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'ene',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'abr',
'L_SHORT_MAY'					=> 'may',
'L_SHORT_JUNE'					=> 'jun',
'L_SHORT_JULY'					=> 'jul',
'L_SHORT_AUGUST'				=> 'ago',
'L_SHORT_SEPTEMBER'				=> 'sep',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dic',
'L_JANUARY'						=> 'enero',
'L_FEBRUARY'					=> 'febrero',
'L_MARCH'						=> 'marzo',
'L_APRIL'						=> 'abril',
'L_MAY'							=> 'mayo',
'L_JUNE'						=> 'junio',
'L_JULY'						=> 'julio',
'L_AUGUST'						=> 'agosto',
'L_SEPTEMBER'					=> 'septiembre',
'L_OCTOBER'						=> 'octubre',
'L_NOVEMBER'					=> 'noviembre',
'L_DECEMBER'					=> 'diciembre',
'L_MONDAY'						=> 'lunes',
'L_TUESDAY'						=> 'martes',
'L_WEDNESDAY'					=> 'miércoles',
'L_THURSDAY'					=> 'jueves',
'L_FRIDAY'						=> 'viernes',
'L_SATURDAY'					=> 'sábado',
'L_SUNDAY'						=> 'domingo',

# class.plx.capcha.php
'L_LAST'						=> 'última',
'L_FIRST'						=> 'primera',
'L_SECOND'						=> 'segunda',
'L_THIRD'						=> 'tercera',
'L_FOURTH'						=> 'cuarta',
'L_FIFTH'						=> 'quinta',
'L_SIXTH'						=> 'sexta',
'L_SEVENTH'						=> 'septima',
'L_EIGTH'						=> 'octava',
'L_NINTH'						=> 'novena',
'L_TENTH'						=> 'décima',
'L_NTH'							=> 'º',
'L_CAPCHA_QUESTION'				=> '¿Cuál es la letra en la <span class="capcha-letter">%s</span> posición de la palabra <span class="capcha-word">%s</span>?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> 'Puede editar %s',
'L_WRITE_NOT_ACCESS'			=> 'No se puede editar %s o no existe',
'L_MODREWRITE_AVAILABLE'		=> 'Módulo de Apache para re-escritura de URLs («mod_rewrite») disponible',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Módulo de Apache para re-escritura de URLs («mod_rewrite») no disponible',
'L_LIBGD_INSTALLED'				=> 'Biblioteca GD instalada',
'L_LIBGD_NOT_INSTALLED'			=> 'Biblioteca GD no instalada',
'L_MAIL_AVAILABLE'				=> 'Función de envío de correos disponible',
'L_MAIL_NOT_AVAILABLE'			=> 'Función de envío de correos no disponible',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'El archivo "%sversion" es necesario para el funcionamiento de PluXml',
'L_ARTICLE_NO_TAG'				=> '¡No existen artículos para esta etiqueta!',
'L_UNKNOWN_CATEGORY'			=> '¡Esta categoría no existe!',
'L_NO_ARTICLE_PAGE'				=> '¡No existen artículos para esta página!',
'L_UNKNOWN_ARTICLE'				=> '¡Este artículo no existe!',
'L_COM_IN_MODERATION'			=> 'Comentario en proceso de moderación por el administrador de este sitio',
'L_UNKNOWN_STATIC'				=> '¡Esta página no existe!',
'L_DOCUMENT_NOT_FOUND'			=> '¡No se encotró el documento especificado!',
'L_NEWCOMMENT_ERR'				=> 'Se ha producido un error al publicar este comentario',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Ingrese todos los campos obligatorios',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Falló La comprobación anti-spam',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compresión %s activada',
'L_PAGETITLE_ARCHIVES'			=> 'Archivos',
'L_PAGETITLE_TAG'				=> 'Etiqueta',
'L_NO_CATEGORY'					=> 'ninguna categoría',
'L_CATEGORY'					=> 'categoría',
'L_CATEGORIES'					=> 'categorías',
'L_NO_ARTICLE'					=> 'ningún artículo',
'L_ARTICLE'						=> 'artículo',
'L_ARTICLES'					=> 'artículos',
'L_ARTAUTHOR_UNKNOWN'			=> 'desconocido',
'L_ARTTAGS_NONE'				=> 'ninguna',
'L_ARTCHAPO'					=> 'Leer más #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Sindicación RSS de los artículos de esta categoría',
'L_ARTFEED_RSS_TAG'				=> 'Sindicación RSS de los artículos de esta etiqueta',
'L_ARTFEED_RSS'					=> 'Sindicación RSS de los artículos',
'L_NO_COMMENT'					=> 'sin comentarios',
'L_COMMENT'						=> 'comentario',
'L_COMMENTS'					=> 'comentarios',
'L_COMFEED_RSS_ARTICLE'			=> 'Sindicación RSS de los comentarios de este artículo',
'L_COMFEED_RSS'					=> 'Sindicación RSS de los comentarios',
'L_STATICCONTENT_INPROCESS'		=> 'Página en proceso de edición',
'L_SAID'						=> 'ha dicho',

'L_PAGINATION_FIRST_TITLE'		=> 'Ir a la primera página',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Página anterior',
'L_PAGINATION_PREVIOUS'			=> 'anterior',
'L_PAGINATION_NEXT_TITLE'		=> 'Página siguiente',
'L_PAGINATION_NEXT'				=> 'siguiente',
'L_PAGINATION_LAST_TITLE'		=> 'Ir a la última página',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'página %s de %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> '¡Las URLs privadas no han sido inicializadas en sus parámetros de administración!',
'L_FEED_COMMENTS'				=> 'Comentarios',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentarios de usuarios',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentarios sin conexión',
'L_FEED_WRITTEN_BY'				=> 'Escrito por',

);
?>

==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/es/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Español',

# common
'L_PLUXML_VERSION'				=> 'Versión de PluXml',
'L_HOMEPAGE'					=> 'Inicio',
'L_UNCLASSIFIED'				=> 'Sin categoría',
'L_INFO_PHP_VERSION'			=> 'Versión de PHP',
'L_INFO_MAGIC_QUOTES'			=> 'Estado de las «comillas mágicas» («magic quotes»)',
'L_INFO_CHARSET'				=> 'codificación',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'No se encontró el tema principal de PluXml',
'L_ERR_FILE_NOTFOUND'			=> 'No se encontró el archivo destino de PluXml',
'L_ERR_PAGE_NOT_FOUND'			=> 'No se encontró la página',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'ene',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'mar',
'L_SHORT_APRIL'					=> 'abr',
'L_SHORT_MAY'					=> 'may',
'L_SHORT_JUNE'					=> 'jun',
'L_SHORT_JULY'					=> 'jul',
'L_SHORT_AUGUST'				=> 'ago',
'L_SHORT_SEPTEMBER'				=> 'sep',
'L_SHORT_OCTOBER'				=> 'oct',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dic',
'L_JANUARY'						=> 'enero',
'L_FEBRUARY'					=> 'febrero',
'L_MARCH'						=> 'marzo',
'L_APRIL'						=> 'abril',
'L_MAY'							=> 'mayo',
'L_JUNE'						=> 'junio',
'L_JULY'						=> 'julio',
'L_AUGUST'						=> 'agosto',
'L_SEPTEMBER'					=> 'septiembre',
'L_OCTOBER'						=> 'octubre',
'L_NOVEMBER'					=> 'noviembre',
'L_DECEMBER'					=> 'diciembre',
'L_MONDAY'						=> 'lunes',
'L_TUESDAY'						=> 'martes',
'L_WEDNESDAY'					=> 'miércoles',
'L_THURSDAY'					=> 'jueves',
'L_FRIDAY'						=> 'viernes',
'L_SATURDAY'					=> 'sábado',
'L_SUNDAY'						=> 'domingo',

# class.plx.capcha.php
'L_LAST'						=> 'última',
'L_FIRST'						=> 'primera',
'L_SECOND'						=> 'segunda',
'L_THIRD'						=> 'tercera',
'L_FOURTH'						=> 'cuarta',
'L_FIFTH'						=> 'quinta',
'L_SIXTH'						=> 'sexta',
'L_SEVENTH'						=> 'septima',
'L_EIGTH'						=> 'octava',
'L_NINTH'						=> 'novena',
'L_TENTH'						=> 'décima',
'L_NTH'							=> 'º',
'L_CAPCHA_QUESTION'				=> '¿Cuál es la <span class="capcha-letter">%s</span> letra en la palabra <span class="capcha-word">%s</span>?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> 'Puede editar %s',
'L_WRITE_NOT_ACCESS'			=> 'No se puede editar %s o no existe',
'L_MODREWRITE_AVAILABLE'		=> 'Módulo de Apache para re-escritura de URLs («mod_rewrite») disponible',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Módulo de Apache para re-escritura de URLs («mod_rewrite») no disponible',
'L_LIBGD_INSTALLED'				=> 'Biblioteca GD instalada',
'L_LIBGD_NOT_INSTALLED'			=> 'Biblioteca GD no instalada',
'L_MAIL_AVAILABLE'				=> 'Función de envío de correos disponible',
'L_MAIL_NOT_AVAILABLE'			=> 'Función de envío de correos no disponible',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'El archivo "%sversion" es necesario para el funcionamiento de PluXml',
'L_ARTICLE_NO_TAG'				=> '¡No existen artículos para esta etiqueta!',
'L_UNKNOWN_CATEGORY'			=> '¡Esta categoría no existe!',
'L_NO_ARTICLE_PAGE'				=> '¡No existen artículos para esta página!',
'L_UNKNOWN_ARTICLE'				=> '¡Este artículo no existe!',
'L_COM_IN_MODERATION'			=> 'Comentario en proceso de moderación por el administrador de este sitio',
'L_UNKNOWN_STATIC'				=> '¡Esta página no existe!',
'L_DOCUMENT_NOT_FOUND'			=> '¡No se encotró el documento especificado!',
'L_NEWCOMMENT_ERR'				=> 'Se ha producido un error al publicar este comentario',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Ingrese todos los campos obligatorios',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Falló La comprobación anti-spam',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compresión %s activada',
'L_PAGETITLE_ARCHIVES'			=> 'Archivos',
'L_PAGETITLE_TAG'				=> 'Etiqueta',
'L_NO_CATEGORY'					=> 'ninguna categoría',
'L_CATEGORY'					=> 'categoría',
'L_CATEGORIES'					=> 'categorías',
'L_NO_ARTICLE'					=> 'ningún artículo',
'L_ARTICLE'						=> 'artículo',
'L_ARTICLES'					=> 'artículos',
'L_ARTAUTHOR_UNKNOWN'			=> 'desconocido',
'L_ARTTAGS_NONE'				=> 'ninguna',
'L_ARTCHAPO'					=> 'Leer más #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Sindicación RSS de los artículos de esta categoría',
'L_ARTFEED_RSS_TAG'				=> 'Sindicación RSS de los artículos de esta etiqueta',
'L_ARTFEED_RSS'					=> 'Sindicación RSS de los artículos',
'L_NO_COMMENT'					=> 'sin comentarios',
'L_COMMENT'						=> 'comentario',
'L_COMMENTS'					=> 'comentarios',
'L_COMFEED_RSS_ARTICLE'			=> 'Sindicación RSS de los comentarios de este artículo',
'L_COMFEED_RSS'					=> 'Sindicación RSS de los comentarios',
'L_STATICCONTENT_INPROCESS'		=> 'Página en proceso de edición',
'L_SAID'						=> 'ha dicho',

'L_PAGINATION_FIRST_TITLE'		=> 'Ir a la primera página',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Página anterior',
'L_PAGINATION_PREVIOUS'			=> 'anterior',
'L_PAGINATION_NEXT_TITLE'		=> 'Página siguiente',
'L_PAGINATION_NEXT'				=> 'siguiente',
'L_PAGINATION_LAST_TITLE'		=> 'Ir a la última página',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'página %s de %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> '¡Las URLs privadas no han sido inicializadas en sus parámetros de administración!',
'L_FEED_COMMENTS'				=> 'Comentarios',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentarios de usuarios',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentarios sin conexión',
'L_FEED_WRITTEN_BY'				=> 'Escrito por',

);
?>
